@@ -15,13 +15,12 @@ from typing import (
     cast,
 )
 
-from di._dag import topsort
-from di._execution_planning import SolvedDependantCache, plan_execution
-from di._inspect import is_async_gen_callable, is_coroutine_callable
-from di._local_scope_context import LocalScopeContext
-from di._nullcontext import nullcontext
-from di._state import ContainerState
-from di._task import AsyncTask, SyncTask, Task
+from di._utils.dag import topsort
+from di._utils.execution_planning import SolvedDependantCache, plan_execution
+from di._utils.inspect import is_async_gen_callable, is_coroutine_callable
+from di._utils.nullcontext import nullcontext
+from di._utils.state import ContainerState, LocalScopeContext
+from di._utils.task import AsyncTask, SyncTask, Task
 from di.exceptions import DuplicateScopeError, SolvingError
 from di.executors import DefaultExecutor
 from di.types import FusedContextManager
@@ -74,7 +73,7 @@ class Container:
     def enter_local_scope(self, scope: Scope) -> FusedContextManager[None]:
         """Enter a local scope that is localized to the current thread or coroutine.
 
-        If you enter a global scope in one thread / coroutine, it will NOT propagate to others.
+        If you enter a local scope in one thread / coroutine, it will NOT propagate to others.
         """
         if scope in self._state.stacks:
             raise DuplicateScopeError(f"Scope {scope} has already been entered!")
@@ -106,9 +105,6 @@ class Container:
         """Solve a dependency.
 
         Returns a SolvedDependant that can be executed to get the dependency's value.
-
-        The `siblings` paramter can be used to pass additional dependencies that should be executed
-        that aren't strictly needed to solve `dependency`.
         """
 
         # If the SolvedDependant itself is a bind, replace it's dependant
@@ -196,33 +192,19 @@ class Container:
     ) -> Dict[DependantBase[Any], Union[AsyncTask[Any], SyncTask[Any]]]:
         tasks: Dict[DependantBase[Any], Union[AsyncTask[Any], SyncTask[Any]]] = {}
         for dep in reversed(topsorted):
-            tasks[dep] = self._build_task(dep, tasks, dag)
+            task_dependencies: List[DependencyParameter[Task[Any]]] = [
+                DependencyParameter(
+                    dependency=tasks[param.dependency], parameter=param.parameter
+                )
+                for param in dag[dep]
+            ]
+
+            if is_async_gen_callable(dep.call) or is_coroutine_callable(dep.call):
+                tasks[dep] = AsyncTask(dependant=dep, dependencies=task_dependencies)
+            else:
+                tasks[dep] = SyncTask(dependant=dep, dependencies=task_dependencies)
         return tasks
 
-    def _build_task(
-        self,
-        dependency: DependantBase[Any],
-        tasks: Dict[DependantBase[Any], Union[AsyncTask[Any], SyncTask[Any]]],
-        dag: Dict[
-            DependantBase[Any],
-            List[DependencyParameter[DependantBase[Any]]],
-        ],
-    ) -> Union[AsyncTask[Any], SyncTask[Any]]:
-
-        task_dependencies: List[DependencyParameter[Task[Any]]] = [
-            DependencyParameter(
-                dependency=tasks[param.dependency], parameter=param.parameter
-            )
-            for param in dag[dependency]
-        ]
-
-        if is_async_gen_callable(dependency.call) or is_coroutine_callable(
-            dependency.call
-        ):
-            return AsyncTask(dependant=dependency, dependencies=task_dependencies)
-        else:
-            return SyncTask(dependant=dependency, dependencies=task_dependencies)
-
     def _update_cache(
         self,
         results: Dict[DependantBase[Any], Any],
@@ -244,6 +226,9 @@ class Container:
     ) -> DependencyType:
         """Execute an already solved dependency.
 
+        This method is synchronous and uses a synchronous executor,
+        but the executor may still be able to execute async dependencies.
+
         If you are not dynamically changing scopes, you can run once with `validate_scopes=True`
         and then disable scope validation in subsequent runs with `validate_scope=False`.
         """
@@ -253,7 +238,7 @@ class Container:
         else:
             cm = self.enter_local_scope(self._execution_scope)
         with cm:
-            results, queue, to_cache = plan_execution(
+            results, leaf_tasks, to_cache = plan_execution(
                 self._state, solved, validate_scopes=validate_scopes, values=values
             )
             if not hasattr(self._executor, "execute_sync"):  # pragma: no cover
@@ -261,8 +246,8 @@ class Container:
                     "execute_sync requires an executor implementing the SyncExecutor protocol"
                 )
             executor = cast(SyncExecutor, self._executor)
-            if queue:
-                executor.execute_sync(queue)
+            if leaf_tasks:
+                executor.execute_sync(leaf_tasks)
             self._update_cache(results, to_cache)
             return results[solved.dependency]  # type: ignore[no-any-return]
 
@@ -284,7 +269,7 @@ class Container:
         else:
             cm = self.enter_local_scope(self._execution_scope)
         async with cm:
-            results, queue, to_cache = plan_execution(
+            results, leaf_tasks, to_cache = plan_execution(
                 self._state, solved, validate_scopes=validate_scopes, values=values
             )
             if not hasattr(self._executor, "execute_async"):  # pragma: no cover
@@ -292,7 +277,7 @@ class Container:
                     "execute_async requires an executor implementing the AsyncExecutor protocol"
                 )
             executor = cast(AsyncExecutor, self._executor)
-            if queue:
-                await executor.execute_async(queue)
+            if leaf_tasks:
+                await executor.execute_async(leaf_tasks)
             self._update_cache(results, to_cache)
             return results[solved.dependency]  # type: ignore[no-any-return]
